@@ -285,6 +285,8 @@ void replaceUnfulfillOperands(Instruction *I){
 
     // loop through operands,
     for (auto &op : I->operands()) {
+        if (isa<InlineAsm>(op))
+            continue;
         if (dominates(op.get(), I))
             continue;
 
@@ -417,8 +419,7 @@ bool isValidTarget(Instruction *I)
         if (calI->isIndirectCall())
             // avoid indirect call
             return false;
-        if (isa<InlineAsm>(calI->getCalledOperand()))
-            // Todo: find a better way to identify a inline assembly
+        if (calI->isInlineAsm())
             return true;
         Function *F = calI->getCalledFunction();
         //avoid touching debuging call
