@@ -5,6 +5,11 @@ import subprocess
 import inspect
 import os
 
+# Error code
+RET_ERROR = 2
+RET_WARNING = 1
+RET_SUCCESS = 0
+
 try:
     import gevo._llvm
     from gevo import __version__
@@ -14,7 +19,7 @@ try:
 except ImportError:
     # TODO: load mutation.so from Mutate folder with proper llvm version string as a standalone mode
     print('Cannot find Mutate.so because gevo is not installed! ')
-    sys.exit(-1)
+    sys.exit(RET_ERROR)
 
 class FileOpener(argparse.FileType):
     # delayed FileType;
@@ -35,10 +40,10 @@ if __name__ == '__main__':
 
     if os.path.isfile(opt_path) is False:
         print(f'{opt_path} does not exist!')
-        sys.exit(-1)
+        sys.exit(RET_ERROR)
     if os.path.isfile(llvm_dis_path) is False:
         print(f'{llvm_dis_path} does not exist!')
-        sys.exit(-1)
+        sys.exit(RET_ERROR)
     
     # Command parser
     class MutationAction(argparse.Action):
@@ -98,7 +103,7 @@ if __name__ == '__main__':
 
     if args.name and 'mutation_commands' in args:
         print("--name and mutation operations cannot be used together.")
-        sys.exit(-1)
+        sys.exit(RET_ERROR)
 
     if args.name:
         opt_proc = subprocess.Popen(
@@ -112,7 +117,7 @@ if __name__ == '__main__':
         if opt_proc.returncode != 0:
             print(f"llvm-mutate: Error in {opt_proc.args}")
             print(opt_stderr.decode(), end='')
-            sys.exit(-1)
+            sys.exit(opt_proc.returncode)
     elif args.ids:
         opt_proc = subprocess.Popen(
             [ opt_path,
@@ -125,9 +130,9 @@ if __name__ == '__main__':
         if opt_proc.returncode != 0:
             print(f"llvm-mutate: Error in {opt_proc.args}")
             print(opt_stderr.decode(), end='')
-            sys.exit(-1)
+            sys.exit(opt_proc.returncode)
         print(opt_stderr.decode(), end='', file=sys.stderr)
-        sys.exit(0)
+        sys.exit(RET_SUCCESS)
     elif args.query:
         opt_proc = subprocess.Popen(
             [ opt_path,
@@ -140,9 +145,9 @@ if __name__ == '__main__':
         if opt_proc.returncode != 0:
             print(f"llvm-mutate: Error in {opt_proc.args}")
             print(opt_stderr.decode(), end='')
-            sys.exit(-1)
+            sys.exit(opt_proc.returncode)
         print(opt_stderr.decode(), end='', file=sys.stdout)
-        sys.exit(0)
+        sys.exit(RET_SUCCESS)
     elif 'mutation_commands' in args:
         with args.input_file.open() as f:
             input_str = f.buffer.read()
@@ -168,20 +173,20 @@ if __name__ == '__main__':
             if opt_proc.returncode != 0:
                 print(f"llvm-mutate: opt error in {mop[0]} {mop[1]}")
                 print(opt_stderr.decode(), end='')
-                sys.exit(-1)
+                sys.exit(opt_proc.returncode)
 
             # TODO: Have proper return code from Mutate.so. irind.py in gevo need to be changed as well
             print(opt_stderr.decode(), end='', file=sys.stderr)
             if opt_stderr.decode().find('failed') != -1:
-                sys.exit(0)
+                sys.exit(RET_SUCCESS)
             if opt_stderr.decode().find('mismatch') != -1:
-                sys.exit(0)
+                sys.exit(RET_SUCCESS)
             if opt_stderr.decode().find('no use') != -1:
-                sys.exit(0)
+                sys.exit(RET_SUCCESS)
             input_str = opt_stdout
     else:
         llvm_mutate_parser.print_help()
-        sys.exit(-1)
+        sys.exit(RET_WARNING)
 
     llvmdis_proc = subprocess.Popen(
         [ llvm_dis_path ],
@@ -192,7 +197,7 @@ if __name__ == '__main__':
     if llvmdis_proc.returncode != 0:
         print(f"llvm-mutate: llc error in \"{' '.join(opt_proc.args)} | {' '.join(llvmdis_proc.args)}\"")
         print(llvmdis_stderr.decode())
-        sys.exit(-1)
+        sys.exit(llvmdis_proc.returncode)
 
     print(llvmdis_stdout.decode(), file=args.output_file.open(), end='')
 
